package com.aucma.report.service;

import java.util.HashMap;
import java.util.List;

import com.aucma.report.domain.ReportQualityInspection;

/**
 * 质检记录管理Service接口
 *
 * @author Yinq
 * @date 2023-11-21
 */
public interface IReportQualityInspectionService {
    /**
     * 查询质检记录管理
     *
     * @param objId 质检记录管理主键
     * @return 质检记录管理
     */
    public ReportQualityInspection selectReportQualityInspectionByObjId(Long objId);

    /**
     * 查询质检记录管理列表
     *
     * @param reportQualityInspection 质检记录管理
     * @return 质检记录管理集合
     */
    public List<ReportQualityInspection> selectReportQualityInspectionList(ReportQualityInspection reportQualityInspection);

    /**
     * 新增质检记录管理
     *
     * @param reportQualityInspection 质检记录管理
     * @return 结果
     */
    public int insertReportQualityInspection(ReportQualityInspection reportQualityInspection);

    /**
     * 修改质检记录管理
     *
     * @param reportQualityInspection 质检记录管理
     * @return 结果
     */
    public int updateReportQualityInspection(ReportQualityInspection reportQualityInspection);

    /**
     * 批量删除质检记录管理
     *
     * @param objIds 需要删除的质检记录管理主键集合
     * @return 结果
     */
    public int deleteReportQualityInspectionByObjIds(Long[] objIds);

    /**
     * 删除质检记录管理信息
     *
     * @param objId 质检记录管理主键
     * @return 结果
     */
    public int deleteReportQualityInspectionByObjId(Long objId);

    /**
     * PDA查询当班质检数量
     *
     * @param reportQualityInspection 质检记录管理
     * @return 质检记录管理集合
     */
    public HashMap<String, Integer> pdaQueryQuantityNumber(String reportQualityInspection);

    /**
     * 箱体码查电检数据
     * @param barcode
     * @param productLineCode
     * @return
     */
    public ReportQualityInspection selectReportQualityInspectionByBarcode(String barcode, String productLineCode);

    /**
     * 检验前一工位是否已完成质检
     * @param boxCode
     * @param stationCode
     * @return
     */
    String checkBeforeStationInspection(String boxCode, String stationCode);
}
