package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import com.aucma.report.domain.BoxTemperatureHistory;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.ReportQualityInspection;
import com.aucma.report.service.IReportQualityInspectionService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 质检记录管理Controller
 *
 * @author Yinq
 * @date 2023-11-21
 */
@RestController
@RequestMapping("/report/qualityInspection" )
public class ReportQualityInspectionController extends BaseController {
    @Autowired
    private IReportQualityInspectionService reportQualityInspectionService;

    /**
     * 查询质检记录管理列表
     */
    @PreAuthorize("@ss.hasPermi('report:qualityInspection:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(ReportQualityInspection reportQualityInspection) {
        startPage();
        List<ReportQualityInspection> list = reportQualityInspectionService.selectReportQualityInspectionList(reportQualityInspection);
        return getDataTable(list);
    }

    /**
     * 导出质检记录管理列表
     */
    @PreAuthorize("@ss.hasPermi('report:qualityInspection:export')" )
    @Log(title = "质检记录管理" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, ReportQualityInspection reportQualityInspection) {
        List<ReportQualityInspection> list = reportQualityInspectionService.selectReportQualityInspectionList(reportQualityInspection);
        ExcelUtil<ReportQualityInspection> util = new ExcelUtil<ReportQualityInspection>(ReportQualityInspection. class);
        util.exportExcel(response, list, "质检记录管理数据" );
    }

    /**
     * 获取质检记录管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:qualityInspection:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(reportQualityInspectionService.selectReportQualityInspectionByObjId(objId));
    }

    /**
     * 新增质检记录管理
     */
    @PreAuthorize("@ss.hasPermi('report:qualityInspection:add')" )
    @Log(title = "质检记录管理" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ReportQualityInspection reportQualityInspection) {
        return toAjax(reportQualityInspectionService.insertReportQualityInspection(reportQualityInspection));
    }

    /**
     * 修改质检记录管理
     */
    @PreAuthorize("@ss.hasPermi('report:qualityInspection:edit')" )
    @Log(title = "质检记录管理" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ReportQualityInspection reportQualityInspection) {
        reportQualityInspection.setUpdatedBy(getUsername());
        reportQualityInspection.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(reportQualityInspectionService.updateReportQualityInspection(reportQualityInspection));
    }

    /**
     * 删除质检记录管理
     */
    @PreAuthorize("@ss.hasPermi('report:qualityInspection:remove')" )
    @Log(title = "质检记录管理" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(reportQualityInspectionService.deleteReportQualityInspectionByObjIds(objIds));
    }
}
